@@ -10,12 +10,14 @@ This module contains utility functions shared between
 metrique sub-modules
 '''
 
+import logging
+logger = logging.getLogger(__name__)
+
 from calendar import timegm
 from datetime import datetime
 from dateutil.parser import parse as dt_parse
 from hashlib import sha1
 import locale
-import logging
 import os
 import pql
 import pytz
@@ -23,8 +25,6 @@ import re
 import simplejson as json
 import sys
 
-logger = logging.getLogger(__name__)
-
 json_encoder = json.JSONEncoder()
 
 DEFAULT_PKGS = ['metrique.cubes']
@@ -373,19 +373,6 @@ def to_encoding(ustring, encoding=None):
         raise ValueError('basestring type required')
 
 
-def set_default(key, default, null_ok=False, err_msg=None):
-    if not err_msg:
-        err_msg = "non-null value required for %s" % key
-    if not null_ok and key is None and default is None:
-            raise RuntimeError(err_msg)
-    try:
-        # if we get 'type' obj, eg `list`
-        result = key if key is not None else default()
-    except (TypeError, AttributeError):
-        result = key if key is not None else default
-    return result
-
-
 def ts2dt(ts, milli=False, tz_aware=True):
     ''' convert timestamp int's (seconds) to datetime objects '''
     # anything already a datetime will still be returned
